@@ -6,12 +6,17 @@
 """
 import datetime
 
+import requests
+
 模块开始 = datetime.datetime.now()
 
-from Fishconsole import fcv
+from lxml import html
+etree = html.etree
 from Fishconsole import logs
-from Fishconsole import helps
 import os
+from Fishconsole import fcv
+from Fishconsole import files
+
 
 
 # 判断设备是否接入网络
@@ -19,7 +24,8 @@ def isConnected():
     import requests
     # noinspection PyBroadException
     try:
-        requests.get("https://pypi.org/project/Fishconsole/", timeout=15)
+
+        requests.get("https://pypi.org/project/Fishconsole/", timeout=7)
     except:
         print(logs.日志("》强制更新系统》官网连接失败"))
         return False
@@ -27,42 +33,90 @@ def isConnected():
     return True
 
 
-logs.系统日志("用户调用了Fishsys模块")
 # 导入强制更新系统所需要的内容
-PI = fcv.f_debug()
-PI = PI["PI"]
-ZUI = fcv.f_debug()
-ZUI = ZUI["ZUI"]
-cache = fcv.f_debug()
-cache = cache["cache"]
-filecheck = fcv.f_debug()
-filecheck = filecheck["filecheck"]
 
 
-def 强制类型检测(任意变量, 预期类型):
+
+
+FI=files.缓存(2,变量名='FI')
+if FI=="error":
+    FI=False
+PI = files.缓存(2, 变量名='PI')
+if PI == "error":
+    PI = False
+ZUI = files.缓存(2, 变量名='ZUI')
+if ZUI == "error":
+    ZUI = False
+
+
+
+
+
+# 新建这个函数，默认情况下所有的项目都不会运行，通过传递的参数开启相应的功能（其实都一样）
+def 系统日志(text, 项目名,开启状态=False):
     """
-
-    Fishconsole Fishsys 强制类型检测
+    Fishconsole 系统日志
 
     ----
 
-    - 就是检测目标变量的类型和指定的类型是不是一样的，如果是一样的，就返回ture，如果不是，就返回False
-
-    - 目标类型可根据所加的其他模块自动适应
-
-    :param 任意变量: 你需要比对的变量
-    :param 预期类型: 你需要验证的类型比如a=1，强制类型检测（a,'int'）
-    :return: bool
+    :param text: 要显示的文字
+    :param 项目名: 这个项目
+    :param 开启状态: 每个项目的布尔值状态（由fcc决定）
+    :return:
     """
-    type值 = str(type(任意变量))
-    变量类型 = type值.split("'")[1]
-    logs.系统日志(f"强制类型检测》展示提取出的变量类型》{变量类型}")
-    if 变量类型 == 预期类型:
-        logs.系统日志(f"强制类型检测》目标判断为真")
-        return True
-    else:
-        logs.系统日志(f"强制类型检测》目标判断为假")
-        return False
+    # 总开关
+    if FI:
+        import time
+        if 开启状态:
+
+            a = logs.颜色(
+                f"Fishconsole{fcv.version()}" + "》" +f"{项目名}"+"》" + str(time.strftime("%Y-%m-%d %H:%M:%S", time.localtime())),
+                色选="紫色") + str(f":{text}")
+            print(a)
+        else:
+            pass
+            # a = logs.颜色(
+            #     f"Fishconsole{version.version()}" + "》" + str(time.strftime("%Y-%m-%d %H:%M:%S", time.localtime())),
+            #     色选="紫色") + str(f":{text}")
+            # print(a)
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
 
 
 # 这是一座屎山，能修则修，不能修就算了
@@ -93,7 +147,8 @@ def passwordsys(模式: any, id_protect: str, password_a: str):
 
     模式 = str(模式)
     if 模式 == "1":
-        logs.系统日志("判断用户输入的值有没有致命问题,顺便拼接一下内容", PI)
+
+        系统日志("判断用户输入的值有没有致命问题,顺便拼接一下内容", "passwordsys", PI)
         res_a = ""
         res_b = ""
         for a in password:
@@ -108,13 +163,13 @@ def passwordsys(模式: any, id_protect: str, password_a: str):
                 logs.安全退出(logs.日志("你的原文中不允许有@符号，请重新输入", 色选="红色"))
 
         else:
-            logs.系统日志("确认成功", PI)
-        logs.系统日志("转移变量的数据", PI)
+            系统日志("确认成功","passwordsys",PI)
+        系统日志("转移变量的数据", "passwordsys",PI)
         password = res_b
         id_protect = res_a
-        logs.系统日志("拼接用户输入的内容", PI)
+        系统日志("拼接用户输入的内容", "passwordsys",PI)
         res = password + "@" + id_protect
-        logs.系统日志("对用户输入的内容进行加密", PI)
+        系统日志("对用户输入的内容进行加密","passwordsys",PI)
         jiami_last = ""
         count = 0
         counta = 0
@@ -340,26 +395,26 @@ def passwordsys(模式: any, id_protect: str, password_a: str):
             logs.安全退出(logs.日志("你输入了非法字符（除1-0，a-z，空格以外其他全是），请检查后重新开始，加密失败", 色选="红色"))
 
         if counta == count:
-            logs.系统日志("通过检查", PI)
-            logs.系统日志(f"Fishconsole》passwordsys》count is {count}", PI)
-            logs.系统日志(f"Fishconsole》passwordsys》counta is {counta}", PI)
+            系统日志("通过检查","passwordsys",PI)
+            系统日志(f"Fishconsole》passwordsys》count is {count}","passwordsys",PI)
+            系统日志(f"Fishconsole》passwordsys》counta is {counta}","passwordsys",PI)
         else:
-            logs.系统日志(f"Fishconsole》passwordsys》count is {count}", PI)
-            logs.系统日志(f"Fishconsole》passwordsys》counta is {counta}", PI)
+            系统日志(f"Fishconsole》passwordsys》count is {count}","passwordsys",PI)
+            系统日志(f"Fishconsole》passwordsys》counta is {counta}","passwordsys",PI)
             logs.安全退出(logs.日志("你输入了非法字符（除1-0，a-z,空格以外其他全是），请检查后重新开始，加密失败", 色选="红色"))
 
-        logs.系统日志("查看加密后的内容", PI)
+        系统日志("查看加密后的内容","passwordsys",PI)
 
         jiami_last = encrypt(jiami_last)
-        logs.系统日志(f"Fishconsole》passwordsys》jiami_last is {jiami_last}", PI)
-        logs.系统日志(f"加密成功", PI)
+        系统日志(f"Fishconsole》passwordsys》jiami_last is {jiami_last}","passwordsys",PI)
+        系统日志(f"加密成功","passwordsys",PI)
         return jiami_last
     else:
         # 解密
 
-        logs.系统日志("验证密码", PI)
+        系统日志("验证密码","passwordsys",PI)
         password_res = [f"{id_protect}"] + [f"{password_a}"]
-        logs.系统日志(f"Fishconsole》passwordsys》password_res is {password_res}", PI)
+        系统日志(f"Fishconsole》passwordsys》password_res is {password_res}","passwordsys",PI)
         p_res = ""
         t_res = ""
         for a in password_res[0]:
@@ -368,18 +423,18 @@ def passwordsys(模式: any, id_protect: str, password_a: str):
             t_res = t_res + a
         jiemi_last = decrypt(t_res)
 
-        logs.系统日志("查看解密加密的内容", PI)
+        系统日志("查看解密加密的内容","passwordsys",PI)
         pattern = re.compile('.{3}')
         a = str(' '.join(pattern.findall(jiemi_last)))
-        logs.系统日志(f"Fishconsole》passwordsys》pattern is {pattern}", PI)
-        logs.系统日志(f"Fishconsole》passwordsys》a is {a}", PI)
+        系统日志(f"Fishconsole》passwordsys》pattern is {pattern}""passwordsys",PI)
+        系统日志(f"Fishconsole》passwordsys》a is {a}""passwordsys",PI)
         # 重新合并加密后的内容
-        logs.系统日志("重新合并数据", PI)
-        logs.系统日志("先将每个转化后的值进行拆分", PI)
+        系统日志("重新合并数据""passwordsys",PI)
+        系统日志("先将每个转化后的值进行拆分""passwordsys",PI)
         pattern_jiemi = (' '.join(pattern.findall(jiemi_last)))
         pattern_jiemi = pattern_jiemi.split(' ')
         pattern_resa = ""
-        logs.系统日志(f"Fishconsole》passwordsys》pattern_jiemi is {pattern_jiemi}", PI)
+        系统日志(f"Fishconsole》passwordsys》pattern_jiemi is {pattern_jiemi}""passwordsys",PI)
         for a in pattern_jiemi:
             if a == "aaa":
                 pattern_resa = pattern_resa + "1"
@@ -526,13 +581,13 @@ def passwordsys(模式: any, id_protect: str, password_a: str):
             if a == "bff":
                 pattern_resa = pattern_resa + "\\"
 
-        logs.系统日志("读取加密信息", PI)
+        系统日志("读取加密信息","passwordsys",PI)
         text = pattern_resa.split("@", 1)[0]
         password = pattern_resa.split("@", 1)[1]
-        logs.系统日志(f"Fishconsole》passwordsys》text is {text}", PI)
-        logs.系统日志(f"Fishconsole》passwordsys》password is {password}", PI)
+        系统日志(f"Fishconsole》passwordsys》text is {text}","passwordsys",PI)
+        系统日志(f"Fishconsole》passwordsys》password is {password}","passwordsys",PI)
         if password == p_res:
-            logs.系统日志("密码验证成功", PI)
+            系统日志("密码验证成功","passwordsys",PI)
             return f"{text}"
         else:
             logs.安全退出(logs.日志("您的密码是错误的，请核对后重新输入"))
@@ -554,15 +609,17 @@ def 密码(模式, 原文, 密码: str = ""):
     :param 密码:  你说是啥子麻
     :return:    操作后的文本
     """
+
+
     if 模式 == 1:
         a = 字符转unicode(1, 原文)
-        logs.系统日志(f"a is {a}", PI)
+        系统日志(f"a is {a}","passwordsys",PI)
         b = passwordsys(1, a, 密码)
-        logs.系统日志(f"b is {b}", PI)
+        系统日志(f"b is {b}","passwordsys",PI)
         return b
     else:
         c = passwordsys(2, 密码, 原文)
-        logs.系统日志(f"c is {c}", PI)
+        系统日志(f"c is {c}","passwordsys",PI)
 
         return c
 
@@ -572,67 +629,11 @@ def 密码(模式, 原文, 密码: str = ""):
 # b = password(2, 3, a)
 
 
-def 网易云音乐(歌单链接: list):
-    """
 
-    Fishconsole Fishsys 网易云音乐模块
-
-    ----
-
-    摸鱼神器，一次只能爬10首歌，这也是为什么歌单要list
-
-
-    :param 歌单链接: 每个歌单的链接就是数组当中的一个值
-    :return: 返回一首歌文件，就在你程序的目录下
-    """
-    a = 强制类型检测(歌单链接, "list")
-    if a:
-        if 官网存活性检测('https://link.hhtjim.com/163/'):
-            import requests
-            from lxml import html
-            etree = html.etree
-            urllist = 歌单链接
-            base_url = 'https://link.hhtjim.com/163/'
-            count = 0
-            for url in urllist:
-                count = count + 1
-                print(logs.颜色(logs.分割线(f"开始第{count}次爬取", "Spider"), 色选="红色"))
-                # noinspection PyBroadException
-                try:
-                    result = requests.get(url).text
-                except:
-                    logs.安全退出("Fishsys》网易云音乐》爬虫》非法内容")
-                dom = etree.HTML(result)
-                # //a[@contains内容(@href指定查找的内容,'song?'含有的)]/@href里面的链接文字
-                ids = dom.xpath('//a[contains(@href,"song?")]/@href')
-                names = dom.xpath('//a[contains(@href,"song?")]/text()')
-                print(ids)
-                a = -1
-                for name in names:
-                    a = a + 1
-                    if not ('$' in name):
-                        if name != "{if x.album}":
-                            if name != "{/if}":
-                                count_id = ids[a].strip("/song?id=")
-                                if not ('$' in count_id):
-                                    song_url = f"{base_url}{count_id}.mp3"
-                                    logs.系统日志(f'存储文件：{name}.mp3')
-                                    music = requests.get(song_url).content
-                                    # noinspection PyBroadException
-                                    try:
-                                        with open(f'{name}.mp3', "wb") as file:
-                                            file.write(music)
-                                            file.close()
-                                    except:
-                                        print(logs.安全退出("Fishsys》网易云音乐》文件写入》写入失败"))
-        else:
-            logs.安全退出("Fishsys》网易云音乐》官网存活性检测》官网连接失败")
-    else:
-        logs.安全退出("Fishsys》网易云音乐》强制类型检测》请输入list类型的数据")
 
 
 def 排名(数据源: list, 第几个: int):
-    b = 强制类型检测(数据源, "list")
+    b = files.强制类型检测(数据源, "list")
     if b:
         第几个 = int(第几个)
         第几个 = 第几个 - 1
@@ -646,82 +647,6 @@ def 排名(数据源: list, 第几个: int):
         logs.安全退出("Fishsys》排名》强制类型检测》请指定list类型的数据源")
 
 
-def 文件存在性检测(文件名: str):
-    """
-
-    Fishconsole Fishsys 文件存在性检测模块
-
-    ----
-
-    :param 文件名:你需要检测的文件
-
-    :return: 布尔值
-    """
-    import os
-    if not os.path.exists(文件名):
-        logs.系统日志("文件存在性检测》文件未被发现，将返回布尔类型的值False", filecheck)
-        file = False
-    else:
-        logs.系统日志("文件存在性检测》文件已被发现，将返回布尔类型的值Ture", filecheck)
-        file = True
-    return file
-
-
-def 缓存(模式, 数据: dict = None, 文件名="Fishconsole.fcc"):
-    """
-
-    Fishconsole Fishsys 缓存模块
-
-    ----
-
-    就是存数据，方便程序在下一次运行的时候调用
-
-
-    模式:1是存储，2是读取
-
-    数据:你要存的数据
-
-    文件名:指定的文件名（默认为Fishconsole.fcc）
-
-    :return:  文件或者dict类型的值，如果没有缓存文件就返回False的布尔值
-    """
-    模式 = str(模式)
-    if 模式 == "1":
-        a = 强制类型检测(数据, 'dict')
-        if a:
-            数据 = str(数据)
-            数据 = passwordsys(1, 数据, "")
-            with open(f'{文件名}', "w") as file:
-                file.write(数据)
-                logs.系统日志("缓存》写入文件完成", cache)
-                logs.系统日志(f"缓存》{文件名}", cache)
-                file.close()
-        else:
-            logs.安全退出("》请使用dict的数据", 数据)
-    elif 模式 == "2":
-        if 文件存在性检测(f"{文件名}"):
-            with open(f'{文件名}', "r") as file:
-                a = file.read()
-                file.close()
-            # noinspection PyBroadException
-            try:
-                解密 = passwordsys(2, "", a)
-            except:
-                logs.安全退出("缓存》你的缓存文件遭到了非法改动，我们无法从中解析数据")
-            解密 = eval(解密)
-            解密 = dict(解密)
-            logs.系统日志("缓存》读取文件完成", cache)
-            logs.系统日志(f"缓存》{文件名}", cache)
-            # 解密 = 解密.split(" ")
-            return 解密
-        else:
-            # 如果它返回这个布尔值，那就说明它没有检测到这个文件
-            logs.系统日志("缓存》文件存在性检测》指定文件并未发现，将返回布尔类型的False")
-            return False
-    else:
-        logs.安全退出("缓存》请选择合法的模式")
-
-
 def 字符转unicode(模式, 原文: str):
     """
     Fishconsole 字符转unicode 模块
@@ -738,27 +663,27 @@ def 字符转unicode(模式, 原文: str):
     原文 = str(原文)
     if 模式 == "1":
         原文 = 原文.encode('unicode_escape')
-        logs.系统日志(f"》Fishconsole》字符串转unicode》type 原文 is {type(原文)}", ZUI)
-        logs.系统日志(f"》Fishconsole》字符串转unicode》原文 is {原文}", ZUI)
+        系统日志(f"》Fishconsole》字符串转unicode》type 原文 is {type(原文)}","字符转unicode", ZUI)
+        系统日志(f"》Fishconsole》字符串转unicode》原文 is {原文}", ZUI)
         原文 = str(原文)
-        logs.系统日志(f"》Fishconsole》字符串转unicode》type 原文 is {type(原文)}", ZUI)
-        logs.系统日志(f"》Fishconsole》字符串转unicode》原文 is {原文}", ZUI)
+        系统日志(f"》Fishconsole》字符串转unicode》type 原文 is {type(原文)}","字符转unicode", ZUI)
+        系统日志(f"》Fishconsole》字符串转unicode》原文 is {原文}","字符转unicode", ZUI)
         return 原文
     elif 模式 == "2":
-        logs.系统日志(f"》Fishconsole》字符串转unicode》type 原文 is {type(原文)}", ZUI)
-        logs.系统日志(f"》Fishconsole》字符串转unicode》原文 is {原文}", ZUI)
+        系统日志(f"》Fishconsole》字符串转unicode》type 原文 is {type(原文)}", "字符转unicode",ZUI)
+        系统日志(f"》Fishconsole》字符串转unicode》原文 is {原文}", "字符转unicode",ZUI)
         b = 原文.replace("b'", "")
         c = b.replace("'", '')
         d = c.encode('utf-8').decode('unicode_escape')
         e = d.replace("nui", r"\u").encode('utf-8').decode('unicode_escape')
-        logs.系统日志(f"》Fishconsole》字符串转unicode》type e is {type(e)}", ZUI)
-        logs.系统日志(f"》Fishconsole》字符串转unicode》e is {e}", ZUI)
+        系统日志(f"》Fishconsole》字符串转unicode》type e is {type(e)}","字符转unicode",ZUI)
+        系统日志(f"》Fishconsole》字符串转unicode》e is {e}","字符转unicode",ZUI)
         return e
     else:
         logs.错误跟踪(["Fishconsole", "字符串转unicode", "模式"], "请选择正确的模式", {模式})
 
 
-def 官网存活性检测(官网地址: str):
+def 官网存活性检测(官网地址: str,测试时长=15):
     """
     Fishconsole Fishsys官网存活性检测
 
@@ -772,10 +697,11 @@ def 官网存活性检测(官网地址: str):
     import requests
     # noinspection PyBroadException
     try:
+        print(logs.日志("尝试对官网进行连接"))
         headers = {
             "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/101.0.4951.64 Safari/537.36 Edg/101.0.1210.53"
         }
-        requests.get(官网地址, headers=headers, timeout=15)
+        requests.get(官网地址, headers=headers, timeout=测试时长)
     except:
         return False
     return True
@@ -822,79 +748,110 @@ def 讯飞云控(fid):
 
 # 你要删我也没办法，反正如果出了什么错过了重大更新你就自己乐呵去呗
 # 这个不是模块，我们将会在导入该模块的时候顺序执行此处
-# 你可以去fcv关闭强制更新而不是删代码
+# 你可以去fcv_debug关闭强制更新而不是删代码,删了对你没有多大好处
 
 # 强制更新系统执行组一期
-sys = fcv.f_debug()
-sys = sys["updata"]
 
-UPI = fcv.f_debug()
-UPI = UPI["updata"]
-# 确认开发者模式是否启动了强制更新
-if sys:
-    logs.系统日志("强制更新系统》强制更新系统启动", UPI)
-    logs.系统日志("强制更新系统》读取缓存信息", UPI)
-    # 查找缓存文件
-    config = 缓存(2)
-    # 如果缓存文件不存在
-    if not config:
-        logs.系统日志("强制更新系统》缓存》缓存文件不存在，创建缓存文件", UPI)
-        # fup的意思是Fishsys模块判断自己是否在之前检测过一次，如果检测过一次，就是修改为正，让它可
-        # +以在下一次检测到版本还是低的话继续保持未检测的状态，如果成功了，那就将False修改为ture，这个fupadta是独立的
-        # +而updata是helps.帮助弄过来的，它的用处就是让Fishsys执行强制更新的操作
+UPI=files.缓存(2,变量名="UPI")
+if UPI=="error":
+    UPI=False
+    temp=files.缓存(2)
+    temp["UPI"]=False
+    files.缓存(1,temp)
 
-        # 因为没有文件，所以我们在一开始就要创建文件，这个创建文件有一个规则，就是需要创建啥就写入啥，不要一股脑全写，因为这样就显得不高效
-        config = {"updata": True, "fup": False, "year": 2022, "month": 5, "day": 20}
-        logs.系统日志("强制更新系统》首次运行，添加fup到缓存", UPI)
-        # 提取数据，其实也是初始化首次启动时要用的变量，因为是第一次启动，所以提取的值就是首次运行的初始值
-        fup = config["fup"]
-        fupdata = config["updata"]
-        year = config['year']
-        # 当变量有点修改的时候我们就要进行保存，因为这样才能避免出现突如其来的故障
-        缓存(1, config)
 
-    else:
-        # 当缓存文件存在时执行的操作
-        logs.系统日志(f"缓存文件存在，尝试读取相关信息", UPI)
-        logs.系统日志(f"Fishconsole.fcc is {config}", UPI)
-        # 因为我们有文件了，我们就可以直接提取数据，但是难免会出现一些奇奇怪怪的情况，所以我们还要检测参数是否存在
-        # 关于fup的信息在822行
-        fup = config.get("fup")
-        fupdata = config.get("updata")
-        year = config.get("year")
-        logs.系统日志(f"fup is {fup}", UPI)
-        logs.系统日志(f"fupdata is {fupdata}", UPI)
-        logs.系统日志(f"year is {year}", UPI)
+UPI=files.缓存(2,变量名="UPI")
+if UPI=="error":
+    UPI=False
+    temp=files.缓存(2)
+    temp["UPI"]=False
+    files.缓存(1,temp)
 
+updata = files.缓存(2, 变量名="updata")
+if updata == "error":
+    updata = True
+    temp=files.缓存(2)
+    temp["updata"]=True
+    files.缓存(1,temp)
+
+Forcedupdate = files.缓存(2, 变量名="Forcedupdate")
+if Forcedupdate == "error":
+    Forcedupdate = True
+    temp=files.缓存(2)
+    temp["Forcedupdate"]=True
+    files.缓存(1,temp)
+
+系统日志("获取变量","强制更新系统", UPI)
+
+
+# 查找缓存文件
+config = files.缓存(2)
+# 如果缓存文件不存在
+if not config:
+    系统日志("强制更新系统》缓存》缓存文件不存在，创建缓存文件","强制更新系统", UPI)
+    # fup的意思是Fishsys模块判断自己是否在之前检测过一次，如果检测过一次，就是修改为正，让它可
+    # +以在下一次检测到版本还是低的话继续保持未检测的状态，如果成功了，那就将False修改为ture，这个fupadta是独立的
+    # +而updata是helps.帮助弄过来的，它的用处就是让Fishsys执行强制更新的操作
+    # 因为没有文件，所以我们在一开始就要创建文件，这个创建文件有一个规则，就是需要创建啥就写入啥，不要一股脑全写，因为这样就显得不高效
+    config = {"updata": True, "fup":True, "year": 2002, "month": 6, "day": 3}
+    系统日志("强制更新系统》首次运行，添加fup到缓存","强制更新系统", UPI)
+    # 提取数据，其实也是初始化首次启动时要用的变量，因为是第一次启动，所以提取的值就是首次运行的初始值
+    fup = config["fup"]
+    updata = config["updata"]
+    year = config['year']
+    # 当变量有点修改的时候我们就要进行保存，因为这样才能避免出现突如其来的故障
+    files.缓存(1, config)
+else:
+    # 当缓存文件存在时执行的操作
+    系统日志(f"缓存文件存在，尝试读取相关信息","强制更新系统", UPI)
+    # 因为我们有文件了，我们就可以直接提取数据，但是难免会出现一些奇奇怪怪的情况，所以我们还要检测参数是否存在
+
+    fup = config.get("fup")
+
+
+    year = config.get("year")
+    day = config.get("day")
+    month = config.get("month")
+    系统日志(f"Forcedupdate is {fup}","强制更新系统", UPI)
+    系统日志(f"fup is {fup}","强制更新系统", UPI)
+    系统日志(f"updata is {updata}","强制更新系统", UPI)
+    系统日志(f"year is {year}","强制更新系统", UPI)
+
+
+# 确认开发者模式是否启动了强制更新，但在之前必须导入变量
+if Forcedupdate:
+    if updata:
+        系统日志("强制更新系统》强制更新系统启动","强制更新系统", UPI)
+        系统日志("强制更新系统》读取缓存信息","强制更新系统", UPI)
         # 如果get到没有的内容，他就会给你返回False的布尔值
-        if year is None:
-            logs.系统日志("year配置不存在，创建", UPI)
-            config["year"] = 2022
-            config["month"] = 5
-            config["day"] = 20
+        if year and month and day  is None:
+            系统日志("year配置不存在，创建","强制更新系统", UPI)
+            config["year"] = 2005
+            config["month"] = 6
+            config["day"] = 11
             上一年 = config.get("year")
             上一月 = config.get("month")
             上一日 = config.get("day")
-            缓存(1, config)
+            files.缓存(1, config)
         else:
             上一年 = config.get("year")
             上一月 = config.get("month")
             上一日 = config.get("day")
 
-        if fupdata is None:
-            logs.系统日志("fupdata配置不存在，创建", UPI)
+        if updata is None:
+            系统日志("updata配置不存在，创建","强制更新系统", UPI)
             config["updata"] = True
-            缓存(1, config)
+            files.缓存(1, config)
+
         if fup is None:
-            logs.系统日志("fup配置不存在，创建", UPI)
+            系统日志("fup配置不存在，创建","强制更新系统", UPI)
             config["fup"] = True
             fup = config["fup"]
-            缓存(1, config)
-    # 计算经过时间，如果经过的时间大于5，我们就要启动自动更新，通过这种被动更新的方式，我们就能确保用户使用的永远是最新版本
+            files.缓存(1, config)
+        # 计算经过时间，如果经过的时间大于5，我们就要启动自动更新，通过这种被动更新的方式，我们就能确保用户使用的永远是最新版本
 
     # 强制更新系统执行组二期
     import time
-
     a = time.strftime("%Y-%m-%d %H:%M:%S", time.localtime())
     a = a.split(" ")[0]
     a = a.split("-")
@@ -917,56 +874,152 @@ if sys:
         上一日 = 3
     # 结束时间就是今天的时间
     # 开始时间就是自上次记录的时间，首次运行所记录的上次的时间默认为我的生日，不管生活有多么狼狈，生日那天也是要好好奖励自己的
-    结束时间 = datetime.datetime(年, 月, 日)
-    开始时间 = datetime.datetime(上一年, 上一月, 上一日)
-
+    try:
+        结束时间 = datetime.datetime(年, 月, 日)
+        开始时间 = datetime.datetime(上一年, 上一月, 上一日)
+    except ValueError:
+        logs.安全退出("强制更新系统》缓存文件遭到非法修改")
     经过时间 = (结束时间 - 开始时间).days
     if 经过时间 >= 5:
         config["updata"] = True
         config["year"] = 年
         config["month"] = 月
         config["day"] = 日
-        缓存(1, config)
-        logs.安全退出("强制更新系统》自动更新》Fishconsole Project自动更新已对您设备上的Fishconsole进行了例行的更新检查》请重新启动本程序进行检查")
+        files.缓存(1, config)
+        print(logs.日志("强制更新系统》自动更新》Fishconsole Project自动更新已对您设备上的Fishconsole进行了例行的更新检查","红色"))
 
-    # fupdata在前面的参数提取中搞就已经好了，现在我们只需要执行操作了
-    if fupdata:
-        logs.系统日志("这是updata值为True时执行的操作", UPI)
-        # 查找fup的变量值，关于fup的介绍在822行，他肯定是存在的，如果不存在的就跑不到这一步了
-        # 这是fup开启时执行的操作
+
+        # updata在前面的参数提取中搞就已经好了，现在我们只需要执行操作了
+    if updata:
+        系统日志("这是updata值为True时执行的操作","强制更新系统", UPI)
+         # 查找fup的变量值，关于fup的介绍在822行，他肯定是存在的，如果不存在的就跑不到这一步了
+         # 这是fup开启时执行的操作
         if fup:
             # 这是fup开启时执行的操作
             res = isConnected()
+            logs.变量查看("res",res)
+            # 反转变量值，这样就可以在下一次执行的时候触发更新
+            config["fup"] = False
+            files.缓存(1, config)
             if res:
                 # 返回值不是False，就说明官网存活，也说明我们链接上了官网
                 print(logs.日志(f"》Fishconsole强制更新系统{fcv.version()}》Fishsys 》您的版本过低，我们将尝试自动为您更新", "红色"))
                 # 最原始的操作，大家引以为戒
                 # os.remove("Fishconsole.fcc")
-                logs.系统日志(f"fup is {fup}", UPI)
-                # 反转变量值，这样就可以在下一次执行的时候触发更新
-                config["fup"] = False
-                缓存(1, config)
-                os.system("python.exe -m pip install --upgrade pip -i https://pypi.douban.com/simple")
-                os.system(f'pip install Fishconsole --upgrade')
+                系统日志(f"fup is {fup}","强制更新系统", UPI)
+                try:
+                    os.system("python.exe -m pip install --upgrade pip -i https://pypi.douban.com/simple")
+                    os.system(f'pip install Fishconsole --upgrade')
+                except:
+                    logs.安全退出("强制更新系统，pip命令组出现未知错误，程序强制退出")
                 logs.安全退出("更新完毕，请重新运行")
-            print(logs.日志("官网链接失败", "红色"))
-
+            else:
+                logs.安全退出("强制更新系统》官网链接失败")
         else:
             # 这是Fishsys的复检或者是没有fup变量时执行的操作
             print(logs.日志(f"》Fishconsole强制更新系统{fcv.version()}》Fishsys 》正在激活帮助及模块包更新检查工具", "红色"))
             # 反转变量值，这样就可以在下一次时触发警告
             config["fup"] = True
             # 只要缓存出现一次变化，我们就要把他存到fcc当中，只有这样我们才能保证它在异常关闭的时候数据不会丢失
-            缓存(1, config)
-            helps.帮助()
-    else:
-        logs.系统日志("这是updata值为False时执行的操作", UPI)
-        config["fup"] = True
-        缓存(1, config)
+            files.缓存(1, config)
+
+            UPI = files.缓存(2, 变量名="UPI")
+            if UPI == "error":
+                UPI = False
+            
+            Forcedupdate = files.缓存(2, 变量名="Forcedupdate")
+            if Forcedupdate == "error":
+                Forcedupdate = True
+            
+            sys = files.缓存(2, 变量名="updata")
+            if sys == "error":
+                sys = True
+            
+
+            
+            系统日志(f"读取缓存信息Foreceupdata [{Forcedupdate}]", "强制更新系统help", UPI)
+            系统日志(f"读取缓存信息sys[{sys}]", "强制更新系统help", UPI)
+
+            系统日志(f"这是强制更新系统开启时的操作", "强制更新系统help", UPI)
+            isConnected = 官网存活性检测("https://pypi.org/project/Fishconsole/")
+            if Forcedupdate:
+                if isConnected:
+                    系统日志(f"检测到网络连接成功", "强制更新系统help", UPI)
+                    print(logs.日志(f"Fishconsole{fcv.version()} 检查更新开始。。。"))
+                    v = fcv.version()
+                    url = "https://pypi.org/project/Fishconsole/"
+                    res = requests.get(url).text
+                    res_html = etree.HTML(res)
+                    res_v = res_html.xpath("/html/body/main/div[2]/div/div[1]/h1/text()")[0]
+                    res_v = str(res_v[21:27])
+                    系统日志(f"res_v is {res_v}", "强制更新系统help", UPI)
+                    系统日志(f"v is {v}", "强制更新系统help", UPI)
+                    # 开启了强制更新系统
+                    if res_v == v:
+                        print(logs.日志(f"Fishconsole{fcv.version()} 检查更新结束,您的模块为最新版本", "绿色"))
+                        print(logs.日志(f"Fishconsole{fcv.version()} 已解锁，您可以使用了", "绿色"))
+                        # 尝试获取缓存中的值
+                        config = files.缓存(2)
+                        if config:
+                            系统日志("这是缓存获取成功时执行的操作", "强制更新系统helps", UPI)
+                            config["updata"] = False
+                            files.缓存(1, config)
+                            config["year"] = 2002
+                            config["month"] = 6
+                            config["day"] = 3
+                        else:
+                            系统日志("这是缓存获取失败时执行的操作", "强制更新系统helps", UPI)
+                            config = {"year": 2002, "month": 6, "day": 3, "updata": False}
+                            files.缓存(1, config)
+                    else:
+                        # 对比到版本号不同
+                        系统日志(f"对比到版本号不同", "强制更新系统help", UPI)
+                        print(logs.日志(f"Fishconsole{fcv.version()} 检查更新结束"))
+                        # 尝试获取缓存中的值
+
+                        # 这是没有检查到值或者发现时执行的操作
+                        print(logs.日志(f"检测到最新版本号发生了变化({res_v}>{v})，请重新运行本程序，我们将尝试自动安装最新版本", "红色"))
+                        print(logs.日志(f"Fishconsole 模块已被禁用，解决方式为更新该模块", "红色"))
+                        config = files.缓存(2)
+                        系统日志(f"config is {config}", "强制更新系统help", UPI)
+                        config["updata"] = True
+                        files.缓存(1, config)
+                        logs.安全退出(f"Fishconsole》help》强制更新启动")
+
+
+                else:
+                    print(logs.日志(f"Fishconsole{fcv.version()} 检查更新结束"))
+                    print(logs.日志("你的设备无法访问互联网，请检查网络连接"))
+            else:
+                logs.日志(f"Fishconsole》f_debug》已取消强制更新", "绿色")
+                # 尝试获取缓存中的值
+                config = files.缓存(2)
+                fupdata = config.get("updata")
+                if fupdata:
+                    config["updata"] = False
+                    files.缓存(1, config)
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
 else:
     # 这是关闭了更新时执行的操作
     print(logs.日志(f"Fishconsole{fcv.version()} 开发者您好,我们已经停止了强制更新。请注意，全局配置已重置", "绿色"))
     print(logs.日志(f"Fishconsole{fcv.version()} 已解锁，您可以使用了", "绿色"))
 模块结束 = datetime.datetime.now()
-
-logs.系统日志(f'Fishsys运行时间为：{模块结束 - 模块开始}')
