@@ -7,12 +7,11 @@
 
 """
 
-import datetime
 import sys
-
 from Fishconsole import fcv
 
-模块开始 = datetime.datetime.now()
+
+
 
 
 def 颜色(text, 色选="None"):
@@ -101,39 +100,10 @@ def 日志(text, 色选="Nona"):
         return str(time.strftime("%Y-%m-%d %H:%M:%S", time.localtime())) + str(f":{text}")
 
 
-# 先导入参数，一个是updata的参数FI
-
-FI = fcv.f_debug()
-FI = FI["Fl"]
 
 
-# 新建这个函数，默认情况下所有的项目都不会运行，通过传递的参数开启相应的功能（其实都一样）
-def 系统日志(text, 参数=False):
-    """
-    FishConsole LOGS系统日志模块
-
-    ----
-
-    这个跟你没啥关系，由开发者选项决定是否启动
 
 
-    :param text: 需要显示的文字
-    :param 参数: 特定模块的代号
-    :return: 指定的文字
-    """
-    if FI:
-        import time
-        # 我想精简这个东西，就是用逻辑表达式，如果其中一个条件满足，那就开启这个，但是它只开启一次，下一个使用这个东西传递的参数和自己的参数不一样的话就不开
-        # 现在我要的是默认输出，遇到情况就来个无效语句
-        if 参数:
-            # 这是True时执行的，默认情况下不会执行，但是这里会有一个地方需要注意一下，因为
-            # 参数被改了，所以当参数没有被再次更改为False之前其中的任何跟系统日志有关的内容就不会被输出
-            # 这个。。虽然能跑了，但是好像实现了又好像没实现。。哎。。开摆
-            1 + 1
-        else:
-            a = 颜色(f"Fishconsole{fcv.version()}" + "》" + str(time.strftime("%Y-%m-%d %H:%M:%S", time.localtime())),
-                   色选="紫色") + str(f":{text}")
-            print(a)
 
 
 def 分割线(标题, text, 色选="Nona"):
@@ -156,6 +126,7 @@ def 分割线(标题, text, 色选="Nona"):
         return f"\n\n\n\n\n\n- {标题} -  {text}:\n--------------------------\n"
 
 
+
 def 变量查看(变量名: str, 变量, 色选: str = "红色"):
     """
     FishCosnole LOGS 变量查看模块
@@ -193,6 +164,8 @@ def 变量查看(变量名: str, 变量, 色选: str = "红色"):
     计数器 = 计数器.split(".")[0]
     计数器 = int(计数器)
     计数器 = 计数器 + 22 + 计数器a
+    if 计数器>=100:
+        计数器=100
     print("=" * 计数器)
     print(日志(f"  ||（{颜色('变量名', 色选)}：{变量名}）"))
     print(日志(f"  ||（{颜色('数据', 色选)}：{变量}）"))
@@ -227,6 +200,4 @@ def 安全退出(内容, 变量=None):
 # 全局参数="红色"
 # a = finput("你你你你你你像个傻逼一样", 全局参数)
 # 错误跟踪(["Fishconsole", "logs", "错误跟踪"], "笑死了","哈哈哈")
-系统日志("用户调用了logs模块")
-模块结束 = datetime.datetime.now()
-系统日志(f'logs运行时间为：{模块结束 - 模块开始}')
+
